Combines cleaned CDC vital statistics sections into a single lookup table containing user guide and U.S. data download URLs for each section and year.

build_link_lookup(datas)

Arguments

datas

A named list of cleaned tibbles, one per CDC data section, as returned by clean_all_sections.

Value

A tibble with one row per section/year combination containing:

section

CDC data section name

year

Data year

user_guide_url

URL to the user guide PDF

user_guide_size

Raw file size string of the user guide

us_data_url

URL to the U.S. data zip file

us_data_size

Raw file size string of the U.S. data file

user_guide_size_mb

User guide file size in megabytes

us_data_size_mb

U.S. data file size in megabytes

Rows where either user_guide_url or us_data_url is missing are dropped.