Takes any dataframe and builds a small sample table

build_test_data(dat, nrow = 50)

Arguments

dat

the dataframe to use for the sample table

nrow

is the number of rows in the sample table

Examples

people <- tibble::tibble(
   name = c("Alice", "Bob", "Carol"),
   age = c(25, 30, 28),
   score = c(88.5, 92.0, 79.3)
)
build_test_data(people)
#> # A tibble: 50 × 3
#>    name    age score
#>    <chr> <dbl> <dbl>
#>  1 Alice    25  88.5
#>  2 Bob      30  92  
#>  3 Carol    28  79.3
#>  4 Carol    28  79.3
#>  5 Carol    28  79.3
#>  6 Carol    28  79.3
#>  7 Carol    28  79.3
#>  8 Carol    28  79.3
#>  9 Carol    28  79.3
#> 10 Carol    28  79.3
#> # ℹ 40 more rows