Scrapes all seven CDC vital statistics data sections from the Vital Statistics Online page and returns them as a named list of tibbles in long format.

scrape_all_sections(url)

Arguments

url

URL to the CDC Vital Statistics Online page. Defaults to the current CDC page.

Value

A named list of seven tibbles, one per section, each containing columns: section, subsection, link_text, year, file_size, url, file_type, and file_size_mb.